module GmapsTz
  class Error < StandardError
    def self.from_json(uri, json)
      klass = case json["status"]
              when "INVALID_REQUEST"
                InvalidRequestError
              when "OVER_QUERY_LIMIT"
                OverQueryLimitError
              when "REQUEST_DENIED"
                RequestDeniedError
              when "UNKNOWN_ERROR"
                UnknownError
              when "ZERO_RESULTS"
                ZeroResultsError
              else
                UnexpectedResponseError
              end
      klass.new(uri, json)
    end

    attr_accessor :uri, :body

    def initialize(uri, body)
      @uri = uri
      @body = body
    end
  end

  class InvalidRequestError < Error; end

  class OverQueryLimitError < Error; end

  class RequestDeniedError < Error; end

  class UnknownError < Error; end

  class ZeroResultsError < Error; end

  class InvalidResponseBodyError < Error; end

  class UnexpectedResponseError < Error; end
end